@@ -451,6 +451,8 @@ event_store_rotate_file(struct event_store *es)
 	}
 
 	/* change names in event_store */
+	free(es->event_file_name);
+	free(es->control_file_name);
 	es->event_file_name = strdup(newname);
 	es->control_file_name = astrcat(newname, ".ctl");
 	es->rotate_index = 1000*timestamp + num + 1;
@@ -1041,7 +1043,7 @@ event_store_clean(struct event_store *es)
 	  abort();
   }
 
-  /* the file can only be removed when all the events were succesfully sent
+  /* the file can only be removed when all the events were successfully sent
      (ie. committed both by LS and BS */
   /* That also implies that the event queues are 'empty' at the moment. */
   ef = fopen(es->event_file_name, "r+");
